@@ -48,6 +48,10 @@ if ($is_gcc)
 		$ld =~ s/gcc/g++/;
 	}
 
+	if (!$is_windows)
+	{
+		$ccflags .= ' -pthread';
+	}
 	$lib .= ' -lpthread';
 
 	if ($is_linux || $is_solaris)
@@ -302,6 +306,11 @@ my @constants = (qw(
 	ZMQ_EVENT_MONITOR_STOPPED
 	ZMQ_EVENT_ALL
 
+	ZMQ_EVENT_HANDSHAKE_FAILED_NO_DETAIL
+	ZMQ_EVENT_HANDSHAKE_SUCCEEDED
+	ZMQ_EVENT_HANDSHAKE_FAILED_PROTOCOL
+	ZMQ_EVENT_HANDSHAKE_FAILED_AUTH
+
 	FEATURE_IPC
 	FEATURE_PGM
 	FEATURE_TIPC
